# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _
from fcm_django import admin as fcm_admin
from fcm_django.models import FCMDevice

from jmb.filters.admin import AdvancedSearchModelAdmin
from . import models


class DeviceAdmin(

    fcm_admin.DeviceAdmin, AdvancedSearchModelAdmin
):
    search_fields = ('device_id',)
    advanced_search_fields = (
        ('name__icontains', 'device_id__icontains',),
        ('reference__icontains', 'type',),
        ('registration_id__icontains', 'active',),
        ('version__icontains', 'manufacturer__icontains',),
    )
    list_filter = ('active', 'type')
    fieldsets = (
        (_('general information'), {
            'fields': (
                ('registration_id',),
                ('device_id', 'type'),
                ('version', 'manufacturer',),
                ('reference', 'name',),
            )
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'active')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('date_create', 'date_last_modify')
        }),
    )
    list_display = (
        'device_id', 'type', 'name', 'version', 'manufacturer', 'active', 'reference', 'registration_id',
    )
    list_display_links = ('device_id',)
    readonly_fields = ('date_create', 'date_last_modify')


admin.site.unregister(FCMDevice)
admin.site.register(models.Device, DeviceAdmin)
